﻿using System;
using System.Web.UI;
using System.Data;
using Telerik.Web.UI;

public partial class Default : System.Web.UI.Page
{

	protected void RadImageGallery1_NeedDataSource(object sender, ImageGalleryNeedDataSourceEventArgs e)
	{
        //Loading the watermark image
		System.Drawing.Bitmap imgWatermark = new System.Drawing.Bitmap(MapPath("Images/testWatermark.png"));

        //Creating a DataTable that will be filled with the binary image data, containing the images with the watermark
		DataTable table = new DataTable();
		table.Columns.Add("Title", typeof(string));
		table.Columns.Add("ImageData", typeof(byte[]));

		for (int i = 1; i < 10; i++)
		{
            //Loading original image (in this example the images are named 1.jpg, 2.jpg, etc.)
			System.Drawing.Bitmap image1 = (System.Drawing.Bitmap)System.Drawing.Image.FromFile(Page.MapPath("Images/" + i + ".jpg"), true);
            //Combining the image with the watermakr
			System.Drawing.Bitmap newImage = CombineBitmaps(image1, imgWatermark);
            //Adding the new image as a byte array to the DataTable
			table.Rows.Add("Title" + i, ImageToByte(newImage));
		}

        //Setting the DataSource of the RadImageGallery
		(sender as RadImageGallery).DataSource = table;
	}

    #region private methods for merging the images
    /// <summary>
    /// Converts System.Drawing.Image to byte[]
    /// </summary>
    /// <param name="img">The System.Drawing.Image object that will be converted to byte[]</param>
    /// <returns></returns>
    private static byte[] ImageToByte(System.Drawing.Image img)
    {
        System.Drawing.ImageConverter converter = new System.Drawing.ImageConverter();
        return (byte[])converter.ConvertTo(img, typeof(byte[]));
    }

    /// <summary>
    /// Combines two images by keeping the size of the first image and fitting the second image without changing its ratio
    /// </summary>
    /// <param name="originalImage"></param>
    /// <param name="watermark"></param>
    /// <returns></returns>
    private static System.Drawing.Bitmap CombineBitmaps(System.Drawing.Bitmap originalImage, System.Drawing.Bitmap watermark)
    {
        System.Drawing.Bitmap finalImage = null;

        try
        {
            int width = originalImage.Width;
            int height = originalImage.Height;

            int waterWidth = watermark.Width;
            int waterHeight = watermark.Height;

            if (width / height >= waterWidth / waterHeight)
            {
                waterWidth = watermark.Width * height / waterHeight;
                waterHeight = height;
            }
            else
            {
                waterHeight = waterHeight * width / waterWidth;
                waterWidth = width;
            }

            finalImage = new System.Drawing.Bitmap(width, height);
            using (System.Drawing.Graphics g = System.Drawing.Graphics.FromImage(finalImage))
            {
                g.Clear(System.Drawing.Color.Transparent);
                g.DrawImage(originalImage, new System.Drawing.Rectangle(0, 0, width, height));
                g.DrawImage(watermark, new System.Drawing.Rectangle(
                    width / 2 - waterWidth / 2,
                    height / 2 - waterHeight / 2,
                    waterWidth,
                    waterHeight));
            }

            return finalImage;
        }
        catch (Exception ex)
        {
            if (finalImage != null)
                finalImage.Dispose();

            throw ex;
        }
    }
    #endregion
}

